summary refs log tree commit diff
path: root/synapse
diff options
context:
space:
mode:
Diffstat (limited to 'synapse')
-rw-r--r--synapse/__init__.py2
-rw-r--r--synapse/events/spamcheck.py13
2 files changed, 8 insertions, 7 deletions
diff --git a/synapse/__init__.py b/synapse/__init__.py
index c3016fc6ed..6d1c6d6f72 100644
--- a/synapse/__init__.py
+++ b/synapse/__init__.py
@@ -47,7 +47,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.36.0"
+__version__ = "1.37.0rc1"
 
 if bool(os.environ.get("SYNAPSE_TEST_PATCH_LOG_CONTEXTS", False)):
     # We import here so that we don't have to install a bunch of deps when
diff --git a/synapse/events/spamcheck.py b/synapse/events/spamcheck.py
index 45ec96dfc1..efec16c226 100644
--- a/synapse/events/spamcheck.py
+++ b/synapse/events/spamcheck.py
@@ -109,6 +109,8 @@ def load_legacy_spam_checkers(hs: "synapse.server.HomeServer"):
             if f is None:
                 return None
 
+            wrapped_func = f
+
             if f.__name__ == "check_registration_for_spam":
                 checker_args = inspect.signature(f)
                 if len(checker_args.parameters) == 3:
@@ -133,19 +135,18 @@ def load_legacy_spam_checkers(hs: "synapse.server.HomeServer"):
                             request_info,
                         )
 
-                    f = wrapper
+                    wrapped_func = wrapper
                 elif len(checker_args.parameters) != 4:
                     raise RuntimeError(
                         "Bad signature for callback check_registration_for_spam",
                     )
 
             def run(*args, **kwargs):
-                # We've already made sure f is not None above, but mypy doesn't do well
-                # across function boundaries so we need to tell it f is definitely not
-                # None.
-                assert f is not None
+                # mypy doesn't do well across function boundaries so we need to tell it
+                # wrapped_func is definitely not None.
+                assert wrapped_func is not None
 
-                return maybe_awaitable(f(*args, **kwargs))
+                return maybe_awaitable(wrapped_func(*args, **kwargs))
 
             return run